pub struct CreateDirectoryOutcome { /* private fields */ }Expand description
Result returned after a directory creation request.
Examples
use qubit_fs::directory::CreateDirectoryOutcome;
let outcome = CreateDirectoryOutcome::new(false);
assert!(!outcome.already_existed());Implementations
Sourceimpl CreateDirectoryOutcome
impl CreateDirectoryOutcome
Sourcepub const fn new(already_existed: bool) -> Self
pub const fn new(already_existed: bool) -> Self
Creates an outcome. already_existed reports an accepted existing
directory.
Sourcepub const fn already_existed(self) -> bool
pub const fn already_existed(self) -> bool
Returns whether an existing directory satisfied the request.
Sourcepub const fn with_created_ancestors(self, count: u64) -> Self
pub const fn with_created_ancestors(self, count: u64) -> Self
Attaches the number of ancestor directories created, when known.
Sourcepub const fn created_ancestors(self) -> Option<u64>
pub const fn created_ancestors(self) -> Option<u64>
Returns the number of created ancestor directories, when reported.