FileSystems

Enum FileSystems 

pub enum FileSystems {}
Global filesystem registry facade.

FileSystems is an uninhabited namespace type. It cannot be instantiated and only exposes static methods backed by a process-wide registry.

Implementations

Source

impl FileSystems

pub fn register<P>(provider: P) -> FsResult<()>
where P: ServiceProvider<FileSystemSpec> + 'static,

Registers a filesystem provider in the global registry.

Parameters
  • provider: Filesystem provider to register.
Errors

Returns an error when a provider with the same descriptor already exists.

pub fn register_shared(provider: Arc<FileSystemProvider>) -> FsResult<()>

Registers a shared filesystem provider in the global registry.

Parameters
  • provider: Shared filesystem provider to register.
Errors

Returns an error when a provider with the same descriptor already exists.

pub fn fs(uri: &str) -> FsResult<Arc<dyn FileSystem>>

Resolves a URI into a filesystem instance from the global registry.

Parameters
  • uri: Filesystem URI.
Returns

A filesystem instance created by the matching provider.

Errors

Returns an error when the URI cannot be parsed or no provider can create a filesystem for the URI scheme.

pub fn fs_for_uri(uri: &FsUri) -> FsResult<Arc<dyn FileSystem>>

Resolves a parsed URI into a filesystem instance from the global registry.

Parameters
  • uri: Parsed filesystem URI.
Returns

A filesystem instance created by the matching provider.

Errors

Returns an error when no provider can create a filesystem for the URI scheme.

pub fn fs_for_scheme(scheme: &str) -> FsResult<Arc<dyn FileSystem>>

Resolves a filesystem instance from a URI scheme.

This is equivalent to resolving the minimal URI {scheme}:///. It is only suitable for providers that can be created from default authority, root path, and default options.

Parameters
  • scheme: URI scheme used to select a provider.
Returns

A filesystem instance created by the matching provider.

Errors

Returns an error when the scheme cannot form a valid URI or no provider can create a filesystem from the minimal URI.

pub fn resource(uri: &str) -> FsResult<FileResource>

Resolves a URI into a bound file resource from the global registry.

Parameters
  • uri: Filesystem URI.
Returns

A file resource containing the matching filesystem and filesystem-local path.

Errors

Returns an error when the URI cannot be parsed or no provider can create a filesystem for the URI scheme.

pub fn resource_for_uri(uri: &FsUri) -> FsResult<FileResource>

Resolves a parsed URI into a bound file resource from the global registry.

Parameters
  • uri: Parsed filesystem URI.
Returns

A file resource containing the matching filesystem and filesystem-local path.

Errors

Returns an error when no provider can create a filesystem for the URI scheme.

pub fn provider_names() -> Vec<String>

Lists provider names registered in the global registry.

Returns

Registered provider names.