FsErrorKind

Enum FsErrorKind 

pub enum FsErrorKind {
Show 17 variants NotFound, AlreadyExists, NotDirectory, IsDirectory, InvalidPath, PermissionDenied, AuthenticationFailed, ProviderUnavailable, UnsupportedOperation, Conflict, PreconditionFailed, Timeout, Interrupted, QuotaExceeded, DataCorruption, Io, Other,
}
Provider-neutral filesystem error category.

Variants



NotFound

The requested resource does not exist.



AlreadyExists

The target resource already exists.



NotDirectory

A path component expected to be a directory is not a directory.



IsDirectory

The requested operation expected a file but found a directory.



InvalidPath

A path or URI is invalid for the selected filesystem.



PermissionDenied

The current credentials do not grant the requested operation.



AuthenticationFailed

Authentication failed before authorization could be evaluated.



ProviderUnavailable

The selected provider is unavailable in the current environment.



UnsupportedOperation

The filesystem model does not support the requested operation.



Conflict

The operation conflicts with current filesystem state.



PreconditionFailed

A conditional operation failed its precondition.



Timeout

The operation timed out.



Interrupted

The operation was interrupted.



QuotaExceeded

A quota, capacity, or storage limit was exceeded.



DataCorruption

Stored or transferred data failed integrity validation.



Io

A lower-level local or remote I/O error occurred.



Other

An error occurred that does not fit a more specific category.