#[non_exhaustive]pub enum FsEffectState {
Unchanged,
PartiallyApplied,
Applied,
Indeterminate,
}Expand description
Strongest known effect that a failed filesystem operation had on storage.
Examples
use qubit_fs::error::FsEffectState;
let unchanged = FsEffectState::Unchanged;
assert!(matches!(unchanged, FsEffectState::Unchanged));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unchanged
The provider proved that the requested mutation did not occur.
PartiallyApplied
Some requested changes occurred, but the operation did not complete.
Applied
The requested namespace or data change occurred before a later failure.
Indeterminate
The provider cannot determine whether the requested change occurred.