FileSystemCapability

Enum FileSystemCapability 

#[non_exhaustive]
#[repr(u8)]
pub enum FileSystemCapability {
Show 28 variants List = 0, Read = 1, RangeRead = 2, ConditionalRead = 3, ChecksumValidation = 4, Write = 5, Append = 6, ConditionalWrite = 7, CreateDirectory = 8, EmptyDirectory = 9, Delete = 10, RecursiveDelete = 11, ConditionalDelete = 12, Rename = 13, AtomicRename = 14, AtomicReplace = 15, Copy = 16, ServerSideCopy = 17, Symlink = 18, TempFile = 19, TempDirectory = 20, AtomicTempPersist = 21, AtomicFileCopy = 22, AtomicTreeCopy = 23, DurableFileCopy = 24, DurableTreeCopy = 25, DurableRename = 26, DurableWrite = 27,
}
A stable operation or semantic guarantee advertised by a filesystem.

Examples

use qubit_fs::metadata::FileSystemCapability;

assert!(matches!(FileSystemCapability::Read, FileSystemCapability::Read));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


List = 0

Directory or prefix listing.



Read = 1

Sequential byte reads.



RangeRead = 2

Required byte-range reads.



ConditionalRead = 3

Version-conditional reads.



ChecksumValidation = 4

Provider-backed checksum validation for reads.



Write = 5

File or object writes.



Append = 6

Append writes.



ConditionalWrite = 7

Conditional writes.



CreateDirectory = 8

Directory creation.



EmptyDirectory = 9

Native empty-directory representation.



Delete = 10

Resource deletion.



RecursiveDelete = 11

Recursive directory or prefix deletion.



ConditionalDelete = 12

Version-conditional deletion.



Rename = 13

Rename or move.



AtomicRename = 14

Atomic rename.



AtomicReplace = 15

Atomic replacement publication.



Copy = 16

Application-visible copy support supplied by a provider TryCopy operation or the facade’s allowlisted stream fallback.



ServerSideCopy = 17

Server-side copy without downloading payload bytes.

Symbolic links.



TempFile = 19

Native or configured temporary files.



TempDirectory = 20

Native or configured temporary directories.



AtomicTempPersist = 21

Atomic temporary-resource persistence.



AtomicFileCopy = 22

Atomic publication of a copied regular file or object.



AtomicTreeCopy = 23

Atomic publication of a copied directory tree or prefix.



DurableFileCopy = 24

Durable publication of a copied regular file or object.



DurableTreeCopy = 25

Durable publication of a copied directory tree or prefix.



DurableRename = 26

Durable publication of a renamed resource.



DurableWrite = 27

Durable publication of a completed write session.

Implementations

Source

impl FileSystemCapability

pub const ALL: &'static [Self]

Stable list of every capability known by this crate version.