Path and URI models.
Structs
- Connection
Uri - A connection URI whose normal formatting always redacts credentials.
- Path
- A validated logical path independent of any provider-native representation.
- Path
Component - A non-empty logical component that cannot express hierarchy or traversal.
- Path
Components - Iterator over the path’s lexical component boundaries.
- Path
Constraints - Immutable path form constraints attached to one filesystem snapshot.
- Relative
Path - A non-empty normalized relative path that cannot escape its base.
- Uri
- A validated URI that cannot contain sensitive credentials or a fragment.
Enums
- Path
Form - Permitted absolute or relative form for paths accepted by a filesystem.
- Path
Semantics - Provider path semantics.