StatResponse

Struct StatResponse 

pub struct StatResponse { /* private fields */ }
Provider metadata response bound to the path it describes.

Examples

use qubit_fs::metadata::{FileKind, FileMetadata};
use qubit_fs::path::Path;
use qubit_fs::spi::StatResponse;

let response = StatResponse::new(
    Path::parse("/object")?,
    FileMetadata::new(FileKind::File),
);
assert_eq!("/object", response.path().as_str());

Implementations

Source

impl StatResponse

pub fn new(path: Path, metadata: FileMetadata) -> Self

Creates a response for path after provider metadata lookup.

Parameters
  • path: Logical path described by the metadata.
  • metadata: Provider metadata snapshot.
Returns

A path-bound metadata response.

pub const fn path(&self) -> &Path

Returns the logical path represented by the metadata.

Returns

The response path.

pub const fn metadata(&self) -> &FileMetadata

Returns the metadata snapshot.

Returns

The provider metadata snapshot.