AsyncDirectoryStreamSession

Trait AsyncDirectoryStreamSession 

pub trait AsyncDirectoryStreamSession: Send {
    // Required method
    fn next_entry_async(&mut self) -> SpiFuture<'_, FsResult<Option<DirEntry>>>;
}
Provider session underlying a concrete crate::directory::AsyncDirectoryStream.

Examples

use qubit_fs::spi::AsyncDirectoryStreamSession;

fn accepts_session<T: AsyncDirectoryStreamSession>() {}

Required Methods

fn next_entry_async(&mut self) -> SpiFuture<'_, FsResult<Option<DirEntry>>>

Asynchronously reads the next directory entry or provider page.

Returns

A future resolving to one entry or None at end of enumeration.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors