pub struct FsPath { /* private fields */ }Expand description
Provider-local filesystem path.
Implementations
Sourceimpl FsPath
impl FsPath
Sourcepub fn is_absolute(&self) -> bool
pub fn is_absolute(&self) -> bool
Sourcepub fn parent(&self) -> Option<Self>
pub fn parent(&self) -> Option<Self>
Gets this path’s parent.
Returns
Some parent path when the path has one, or None for root and
parentless relative paths.
Sourcepub fn file_extension(&self) -> Option<&str>
pub fn file_extension(&self) -> Option<&str>
Gets the final path component extension.
Returns
Some extension without the dot when the final path component has a
non-empty extension, or None for root, extensionless names, hidden
names such as .profile, and names ending with a dot.