pub enum WriterState {
Open,
Committed,
NotPublished,
Published,
Aborted,
Indeterminate,
}Expand description
Observable lifecycle state of a synchronous or asynchronous file writer.
Examples
use qubit_fs::write::WriterState;
assert!(matches!(WriterState::Open, WriterState::Open));Variants
Open
The session accepts bytes and may be committed or aborted.
Committed
Publication completed successfully.
NotPublished
Publication definitely did not occur and only cleanup remains possible.
Published
Publication occurred, but provider cleanup remains possible.
Aborted
The session was explicitly cancelled and cleaned up.
Indeterminate
Publication or lifecycle cleanup may have occurred, but the provider cannot confirm the final state.