AsyncCopyFailure

Struct AsyncCopyFailure 

pub struct AsyncCopyFailure { /* private fields */ }
Copy failure facts retained after an asynchronous copy operation.

Examples

use qubit_fs::copy::{AsyncCopyFailure, CopyFailureState, CopyStats};
use qubit_fs::error::{FsError, FsErrorKind, FsOperation};

assert!(std::any::type_name::<AsyncCopyFailure>().contains("AsyncCopyFailure"));
let error = FsError::new(FsErrorKind::Io, FsOperation::Copy, "interrupted");
assert_eq!(CopyFailureState::Unchanged, CopyFailureState::Unchanged);
assert_eq!(0, CopyStats::default().bytes);
assert_eq!(FsOperation::Copy, error.operation());

Implementations

Source

impl AsyncCopyFailure

pub const fn error(&self) -> &FsError

Returns the contextual filesystem error.

pub const fn state(&self) -> CopyFailureState

Returns the confirmed publication state.

pub const fn partial_stats(&self) -> &CopyStats

Returns partial transfer statistics.

pub fn into_parts(self) -> (FsError, CopyFailureState, CopyStats)

Splits the failure into owned error, state, and progress facts.